Reviewers: Hannes Payer,

Description:
Deprecate IdleNotification()

Embedders should use IdleNotificationDeadline()

BUG=none
[email protected]
LOG=y

Please review this at https://codereview.chromium.org/1019793008/

Base URL: https://chromium.googlesource.com/v8/v8.git@master

Affected files (+7, -7 lines):
  M include/v8.h


Index: include/v8.h
diff --git a/include/v8.h b/include/v8.h
index 51fae0e564f0c752284a77e411fd37378c7a84c6..903a4fb5753a993495eff094d0e4d83f5ef89010 100644
--- a/include/v8.h
+++ b/include/v8.h
@@ -5350,8 +5350,9 @@ class V8_EXPORT Isolate {
    *
* This should only be used for testing purposes and not to enforce a garbage
    * collection schedule. It has strong negative impact on the garbage
  * collection performance. Use IdleNotification() or LowMemoryNotification()
    * instead to influence the garbage collection schedule.
    */
   void RequestGarbageCollectionForTesting(GarbageCollectionType type);

@@ -5433,22 +5434,21 @@ class V8_EXPORT Isolate {
    * Optional notification that the embedder is idle.
    * V8 uses the notification to perform garbage collection.
    * This call can be used repeatedly if the embedder remains idle.
    * Returns true if the embedder should stop calling IdleNotification
    * until real work has been done.  This indicates that V8 has done
    * as much cleanup as it will be able to do.
    *
-   * The idle_time_in_ms argument specifies the time V8 has to perform
-   * garbage collection. There is no guarantee that the actual work will be
-   * done within the time limit.
* The deadline_in_seconds argument specifies the deadline V8 has to finish
    * garbage collection work. deadline_in_seconds is compared with
* MonotonicallyIncreasingTime() and should be based on the same timebase as
    * that function. There is no guarantee that the actual work will be done
    * within the time limit.
    */
-  bool IdleNotification(int idle_time_in_ms);
   bool IdleNotificationDeadline(double deadline_in_seconds);

+  V8_DEPRECATED_SOON("use IdleNotificationDeadline()",
+                     bool IdleNotification(int idle_time_in_ms));
+
   /**
    * Optional notification that the system is running low on memory.
    * V8 uses these notifications to attempt to free memory.
@@ -5350,8 +5350,9 @@ class V8_EXPORT Isolate {
* This should only be used for testing purposes and not to enforce a garbage
    * collection schedule. It has strong negative impact on the garbage
- * collection performance. Use IdleNotification() or LowMemoryNotification()
-   * instead to influence the garbage collection schedule.
+   * collection performance. Use IdleNotificationDeadline() or
+   * LowMemoryNotification() instead to influence the garbage collection
+   * schedule.
    */
   void RequestGarbageCollectionForTesting(GarbageCollectionType type);
@@ -5433,22 +5434,21 @@ class V8_EXPORT Isolate {
    * V8 uses the notification to perform garbage collection.
    * This call can be used repeatedly if the embedder remains idle.
-   * Returns true if the embedder should stop calling IdleNotification
+ * Returns true if the embedder should stop calling IdleNotificationDeadline
    * until real work has been done.  This indicates that V8 has done
    * as much cleanup as it will be able to do.


--
--
v8-dev mailing list
[email protected]
http://groups.google.com/group/v8-dev
--- You received this message because you are subscribed to the Google Groups "v8-dev" group.
To unsubscribe from this group and stop receiving emails from it, send an email 
to [email protected].
For more options, visit https://groups.google.com/d/optout.

Reply via email to